home

package
v0.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 26, 2026 License: MIT Imports: 2 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Dir

func Dir() string

Dir returns the user's home directory. It calls os.Exit(1) if the home directory cannot be determined. Use this for critical paths where an empty home would cause data to be written to the wrong location.

Types

This section is empty.

Jump to