Documentation
¶
Overview ¶
Package types provides shared types used across GrayCodeAI hawk-related modules. Severity, TokenSeverity, and AuditSeverity are forwarded from the shared package. ToolCall and ToolResult come from eyrie/client.
Index ¶
- Constants
- Variables
- type Attribution
- type AuditSeverity
- type ChatOptions
- type ContinuationConfig
- type EyrieClient
- type EyrieConfig
- type EyrieMessage
- type EyrieResponse
- type EyrieStreamEvent
- type EyrieTool
- type EyrieUsage
- type Provider
- type Severity
- type StreamResult
- type TokenSeverity
- type ToolCall
- type ToolResult
Constants ¶
const ( SeverityInfo = types.SeverityInfo SeverityLow = types.SeverityLow SeverityMedium = types.SeverityMedium SeverityHigh = types.SeverityHigh SeverityCritical = types.SeverityCritical )
const ( TokenSeverityCritical = types.TokenSeverityCritical TokenSeverityHigh = types.TokenSeverityHigh TokenSeverityMedium = types.TokenSeverityMedium TokenSeverityLow = types.TokenSeverityLow )
const ( AuditSeverityCritical = types.AuditSeverityCritical AuditSeverityWarning = types.AuditSeverityWarning AuditSeverityInfo = types.AuditSeverityInfo )
Variables ¶
var ParseSeverity = types.ParseSeverity
ParseSeverity converts a string to a Severity.
Functions ¶
This section is empty.
Types ¶
type Attribution ¶
type AuditSeverity ¶
type AuditSeverity = types.AuditSeverity
AuditSeverity indicates how dangerous a security audit finding is.
type ChatOptions ¶
type ChatOptions = client.ChatOptions
type ContinuationConfig ¶
type ContinuationConfig = client.ContinuationConfig
func DefaultContinuationConfig ¶
func DefaultContinuationConfig() ContinuationConfig
type EyrieClient ¶
type EyrieClient = client.EyrieClient
func NewClient ¶
func NewClient(cfg *EyrieConfig) *EyrieClient
type EyrieConfig ¶
type EyrieConfig = client.EyrieConfig
type EyrieMessage ¶
type EyrieMessage = client.EyrieMessage
type EyrieResponse ¶
type EyrieResponse = client.EyrieResponse
type EyrieStreamEvent ¶
type EyrieStreamEvent = client.EyrieStreamEvent
type EyrieUsage ¶
type EyrieUsage = client.EyrieUsage
type StreamResult ¶
type StreamResult = client.StreamResult
func StreamChatWithContinuation ¶
func StreamChatWithContinuation(ctx context.Context, p Provider, messages []EyrieMessage, opts ChatOptions, cfg ContinuationConfig) (*StreamResult, error)
type TokenSeverity ¶
type TokenSeverity = types.TokenSeverity
TokenSeverity defines rule severity for compression error patterns.
type ToolCall ¶
ToolCall represents a tool invocation requested by the model.
func ParseInlineToolCalls ¶
type ToolResult ¶
type ToolResult = client.ToolResult
ToolResult represents the result of a tool execution.
Click to show internal directories.
Click to hide internal directories.